melobot.mp
==========

多进程支持
-------------

.. autoclass:: melobot.mp.SpawnProcess
    :members:
    :exclude-members: owned

.. autoclass:: melobot.mp.SpawnProcessPool
    :members:

.. autoclass:: melobot.mp.SpawnProcessPoolExecutor
    :members:

.. autoclass:: melobot.mp.PBox
    :members:
